# tomacco
Pomodoro Technique time

# more info
https://en.wikipedia.org/wiki/Pomodoro_Technique

# Install && Usage
- Install
    pip3 install tomacco

- Usage
    Run main script "tomacco"

    "tomacco-cli" can  start/stop/etc from comandline
